White Linen Like Guest Hand Towels - 300 Count | My Paper Shop
Description: Disposable white linen like guest hand towels are made from a high quality paper material that looks & feels like real linen. Free shipping offer available!

View Larger Photo

# White Linen Like Guest Hand Towels - 300 Count

Case Price: $45.95

Product Code: 856802

White Linen-Like® guest towels are made from a high quality soft paper material that looks and feels like real cloth linen, but offers the convenience of a disposable product. These Linen Like guest towels are unembossed and can be used as premium disposable hand towels.
© All Rights Reserved.
Note: Guest Towels are folded as shown in photo.

Made In USA

How Many Cases?

Brand: Hoffmaster

Case Quantity: 300 Guest Towels

Inner Pack: 25 per Package / 12 Case

Unfolded Napkin Size: 11.5 Inches x 16.75 Inches (29.21 cm x 42.55 cm).

Folded Napkin Size: 4.5 Inches x 8.5 Inches (11.43 cm x 21.59 cm).

Packaging Type: Poly packaged and barcoded for retail opportunities.

Minimum Order: 1 Full Case. Not available in smaller quantities.

Customers Also Purchased
Clear Plastic Guest Towel Holders
Seagrass Guest Hand Towel Basket
Product Reviews

Customers Reviews (1)

Rating:

Write a Review

Only hand We will buy., 4.28.2015

We use our towels for our patients during eye exams. We want to set ourselves apart from our competition so we use nicer towels for them to use when washing their hands prior to trying on contacts. Patients are impressed.

Reviewer: John Ellis (El Paso, TX)

Copyright © 2000 - 2016 My Paper Shop.Com, Inc. All Rights Reserved.

*MARKER* 0